/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"time"

	v1alpha1 "github.com/litmuschaos/chaos-operator/pkg/apis/litmuschaos/v1alpha1"
	scheme "github.com/litmuschaos/chaos-operator/pkg/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ChaosExperimentsGetter has a method to return a ChaosExperimentInterface.
// A group's client should implement this interface.
type ChaosExperimentsGetter interface {
	ChaosExperiments(namespace string) ChaosExperimentInterface
}

// ChaosExperimentInterface has methods to work with ChaosExperiment resources.
type ChaosExperimentInterface interface {
	Create(*v1alpha1.ChaosExperiment) (*v1alpha1.ChaosExperiment, error)
	Update(*v1alpha1.ChaosExperiment) (*v1alpha1.ChaosExperiment, error)
	UpdateStatus(*v1alpha1.ChaosExperiment) (*v1alpha1.ChaosExperiment, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha1.ChaosExperiment, error)
	List(opts v1.ListOptions) (*v1alpha1.ChaosExperimentList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ChaosExperiment, err error)
	ChaosExperimentExpansion
}

// chaosExperiments implements ChaosExperimentInterface
type chaosExperiments struct {
	client rest.Interface
	ns     string
}

// newChaosExperiments returns a ChaosExperiments
func newChaosExperiments(c *LitmuschaosV1alpha1Client, namespace string) *chaosExperiments {
	return &chaosExperiments{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the chaosExperiment, and returns the corresponding chaosExperiment object, and an error if there is any.
func (c *chaosExperiments) Get(name string, options v1.GetOptions) (result *v1alpha1.ChaosExperiment, err error) {
	result = &v1alpha1.ChaosExperiment{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("chaosexperiments").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ChaosExperiments that match those selectors.
func (c *chaosExperiments) List(opts v1.ListOptions) (result *v1alpha1.ChaosExperimentList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.ChaosExperimentList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("chaosexperiments").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested chaosExperiments.
func (c *chaosExperiments) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("chaosexperiments").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a chaosExperiment and creates it.  Returns the server's representation of the chaosExperiment, and an error, if there is any.
func (c *chaosExperiments) Create(chaosExperiment *v1alpha1.ChaosExperiment) (result *v1alpha1.ChaosExperiment, err error) {
	result = &v1alpha1.ChaosExperiment{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("chaosexperiments").
		Body(chaosExperiment).
		Do().
		Into(result)
	return
}

// Update takes the representation of a chaosExperiment and updates it. Returns the server's representation of the chaosExperiment, and an error, if there is any.
func (c *chaosExperiments) Update(chaosExperiment *v1alpha1.ChaosExperiment) (result *v1alpha1.ChaosExperiment, err error) {
	result = &v1alpha1.ChaosExperiment{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("chaosexperiments").
		Name(chaosExperiment.Name).
		Body(chaosExperiment).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *chaosExperiments) UpdateStatus(chaosExperiment *v1alpha1.ChaosExperiment) (result *v1alpha1.ChaosExperiment, err error) {
	result = &v1alpha1.ChaosExperiment{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("chaosexperiments").
		Name(chaosExperiment.Name).
		SubResource("status").
		Body(chaosExperiment).
		Do().
		Into(result)
	return
}

// Delete takes name of the chaosExperiment and deletes it. Returns an error if one occurs.
func (c *chaosExperiments) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("chaosexperiments").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *chaosExperiments) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("chaosexperiments").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched chaosExperiment.
func (c *chaosExperiments) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.ChaosExperiment, err error) {
	result = &v1alpha1.ChaosExperiment{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("chaosexperiments").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
